@@ -4,6 +4,7 @@ import sys
 import click
 
 from ._utils._common import add_cwd_to_path, load_environment_variables
+from ._utils._context import CliContext
 from .cli_add import add as add
 from .cli_auth import auth as auth
 from .cli_debug import debug as debug  # type: ignore
@@ -20,6 +21,9 @@ from .cli_push import push as push  # type: ignore
 from .cli_register import register as register  # type: ignore
 from .cli_run import run as run  # type: ignore
 
+load_environment_variables()
+add_cwd_to_path()
+
 
 def _get_safe_version() -> str:
     """Get the version of the uipath package."""
@@ -46,9 +50,39 @@ def _get_safe_version() -> str:
     is_flag=True,
     help="Display the current version of uipath.",
 )
-def cli(lv: bool, v: bool) -> None:
-    load_environment_variables()
-    add_cwd_to_path()
+@click.option(
+    "--format",
+    type=click.Choice(["json", "table", "csv"]),
+    default="table",
+    help="Output format for commands",
+)
+@click.option(
+    "--debug",
+    is_flag=True,
+    help="Enable debug logging and show stack traces",
+)
+@click.pass_context
+def cli(
+    ctx: click.Context,
+    lv: bool,
+    v: bool,
+    format: str,
+    debug: bool,
+) -> None:
+    """UiPath CLI - Automate everything.
+
+    \b
+    Examples:
+        uipath new my-project
+        uipath dev
+        uipath deploy
+        uipath buckets list --folder-path "Shared"
+    """  # noqa: D301
+    ctx.obj = CliContext(
+        output_format=format,
+        debug=debug,
+    )
+
     if lv:
         try:
             version = importlib.metadata.version("uipath-langchain")
@@ -64,6 +98,10 @@ def cli(lv: bool, v: bool) -> None:
             click.echo("uipath is not installed", err=True)
             sys.exit(1)
 
+    # Show help if no command was provided (matches docker, kubectl, git behavior)
+    if ctx.invoked_subcommand is None and not lv and not v:
+        click.echo(ctx.get_help())
+
 
 cli.add_command(new)
 cli.add_command(init)
@@ -80,3 +118,7 @@ cli.add_command(dev)
 cli.add_command(add)
 cli.add_command(register)
 cli.add_command(debug)
+
+from .services import register_service_commands  # noqa: E402
+
+register_service_commands(cli)
