@@ -45,8 +45,6 @@ PYTHON_BINARY_EXTENSIONS = {".pickle", ".pkl"}
 
 SPECIAL_EXTENSIONS = {""}  # Extensionless binary files
 
-UIPATH_PROJECT_ID = "UIPATH_PROJECT_ID"
-
 # Pre-compute the union for optimal performance
 BINARY_EXTENSIONS = (
     IMAGE_EXTENSIONS
@@ -60,6 +58,9 @@ BINARY_EXTENSIONS = (
     | SPECIAL_EXTENSIONS
 )
 
+# Directory names
+EVALS_DIRECTORY_NAME = "evals"
+
 
 def is_binary_file(file_extension: str) -> bool:
     """Determine if a file should be treated as binary."""
