@@ -5,7 +5,7 @@ from httpx import Response
 from .._config import Config
 from .._execution_context import ExecutionContext
 from .._folder_context import FolderContext
-from .._utils import Endpoint, RequestSpec, header_folder, infer_bindings
+from .._utils import Endpoint, RequestSpec, header_folder, resource_override
 from ..models import Asset, UserAsset
 from ..tracing._traced import traced
 from ._base_service import BaseService
@@ -25,7 +25,7 @@ class AssetsService(FolderContext, BaseService):
     @traced(
         name="assets_retrieve", run_type="uipath", hide_input=True, hide_output=True
     )
-    @infer_bindings(resource_type="asset")
+    @resource_override(resource_type="asset")
     def retrieve(
         self,
         name: str,
@@ -81,7 +81,7 @@ class AssetsService(FolderContext, BaseService):
     @traced(
         name="assets_retrieve", run_type="uipath", hide_input=True, hide_output=True
     )
-    @infer_bindings(resource_type="asset")
+    @resource_override(resource_type="asset")
     async def retrieve_async(
         self,
         name: str,
@@ -128,7 +128,7 @@ class AssetsService(FolderContext, BaseService):
     @traced(
         name="assets_credential", run_type="uipath", hide_input=True, hide_output=True
     )
-    @infer_bindings(resource_type="asset")
+    @resource_override(resource_type="asset")
     def retrieve_credential(
         self,
         name: str,
@@ -183,7 +183,7 @@ class AssetsService(FolderContext, BaseService):
     @traced(
         name="assets_credential", run_type="uipath", hide_input=True, hide_output=True
     )
-    @infer_bindings(resource_type="asset")
+    @resource_override(resource_type="asset")
     async def retrieve_credential_async(
         self,
         name: str,
