@@ -8,7 +8,7 @@ from typing_extensions import deprecated
 from .._config import Config
 from .._execution_context import ExecutionContext
 from .._folder_context import FolderContext
-from .._utils import Endpoint, RequestSpec, header_folder, infer_bindings
+from .._utils import Endpoint, RequestSpec, header_folder, resource_override
 from .._utils.constants import (
     CONFLUENCE_DATA_SOURCE,
     DROPBOX_DATA_SOURCE,
@@ -51,7 +51,7 @@ class ContextGroundingService(FolderContext, BaseService):
         super().__init__(config=config, execution_context=execution_context)
 
     @traced(name="add_to_index", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     def add_to_index(
         self,
         name: str,
@@ -106,7 +106,7 @@ class ContextGroundingService(FolderContext, BaseService):
             self.ingest_data(index, folder_key=folder_key, folder_path=folder_path)
 
     @traced(name="add_to_index", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     async def add_to_index_async(
         self,
         name: str,
@@ -165,7 +165,7 @@ class ContextGroundingService(FolderContext, BaseService):
             )
 
     @traced(name="contextgrounding_retrieve", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     def retrieve(
         self,
         name: str,
@@ -207,7 +207,7 @@ class ContextGroundingService(FolderContext, BaseService):
             raise Exception("ContextGroundingIndex not found") from e
 
     @traced(name="contextgrounding_retrieve", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     async def retrieve_async(
         self,
         name: str,
@@ -319,7 +319,7 @@ class ContextGroundingService(FolderContext, BaseService):
         return response.json()
 
     @traced(name="contextgrounding_create_index", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     def create_index(
         self,
         name: str,
@@ -377,7 +377,7 @@ class ContextGroundingService(FolderContext, BaseService):
         return ContextGroundingIndex.model_validate(response.json())
 
     @traced(name="contextgrounding_create_index", run_type="uipath")
-    @infer_bindings(resource_type="index")
+    @resource_override(resource_type="index")
     async def create_index_async(
         self,
         name: str,
@@ -435,6 +435,7 @@ class ContextGroundingService(FolderContext, BaseService):
         return ContextGroundingIndex.model_validate(response.json())
 
     @traced(name="contextgrounding_search", run_type="uipath")
+    @resource_override(resource_type="index")
     def search(
         self,
         name: str,
@@ -482,6 +483,7 @@ class ContextGroundingService(FolderContext, BaseService):
         )
 
     @traced(name="contextgrounding_search", run_type="uipath")
+    @resource_override(resource_type="index")
     async def search_async(
         self,
         name: str,
