@@ -12,6 +12,7 @@ ENV_ROBOT_KEY = "UIPATH_ROBOT_KEY"
 ENV_TENANT_ID = "UIPATH_TENANT_ID"
 ENV_ORGANIZATION_ID = "UIPATH_ORGANIZATION_ID"
 ENV_TELEMETRY_ENABLED = "UIPATH_TELEMETRY_ENABLED"
+ENV_UIPATH_PROJECT_ID = "UIPATH_PROJECT_ID"
 
 # Headers
 HEADER_FOLDER_KEY = "x-uipath-folderkey"
@@ -47,6 +48,7 @@ COMMUNITY_agents_SUFFIX = "-community-agents"
 
 # File names
 UIPATH_CONFIG_FILE = "uipath.json"
+UIPATH_BINDINGS_FILE = "bindings.json"
 
 # Evaluators
 CUSTOM_EVALUATOR_PREFIX = "file://"
