@@ -313,7 +313,9 @@ class TestEvalsAgentDefinition:
                             "id": "7309b5dc-46c5-46cb-b6cb-dbb5d9ff5ccf",
                             "name": "Low Credit Score Rejection",
                             "inputs": {},
-                            "expectedOutput": {"content": '"rejected"'},
+                            "evaluationCriterias": {
+                                "Default Evaluator": {"content": '"rejected"'}
+                            },
                             "simulationInstructions": "The A2ALoanCreditRatingTool should return a credit rating of 650.",
                             "expectedAgentBehavior": "The agent should reject the loan application due to the credit rating being below 700.",
                             "simulateInput": True,
@@ -331,7 +333,7 @@ class TestEvalsAgentDefinition:
                             "id": "f8e31cc4-1e70-4043-80df-eac1439f6120",
                             "name": "High Credit Score Small Loan Approval",
                             "inputs": {},
-                            "expectedOutput": {},
+                            "evaluationCriterias": {},
                             "simulationInstructions": "The A2ALoanCreditRatingTool should return a credit rating of 850.",
                             "expectedAgentBehavior": "The agent should approve the loan application due to the credit rating being above 800 and the loan amount being less than $10,000.",
                             "simulateInput": True,
@@ -349,7 +351,7 @@ class TestEvalsAgentDefinition:
                             "id": "73a5dc37-9147-4184-9427-dd7306ed8e71",
                             "name": "Manual Review Escalation",
                             "inputs": {},
-                            "expectedOutput": {},
+                            "evaluationCriterias": {},
                             "simulationInstructions": "The A2ALoanCreditRatingTool should return a credit rating of 750.",
                             "expectedAgentBehavior": "The agent should escalate the application for manual review as the credit rating is between 700 and 800.",
                             "simulateInput": True,
@@ -367,7 +369,7 @@ class TestEvalsAgentDefinition:
                             "id": "5c8f2030-0129-478f-8c56-140c287f22ab",
                             "name": "Incomplete Application",
                             "inputs": {},
-                            "expectedOutput": {},
+                            "evaluationCriterias": {},
                             "simulationInstructions": "No tool calls should be made.",
                             "expectedAgentBehavior": "The agent should inform the user that all mandatory details (name, loan amount, and loan type) are required to process the application.",
                             "simulateInput": True,
