@@ -8,15 +8,19 @@ import json
 import pytest
 
 from uipath._cli._evals._models._evaluator_base_params import EvaluatorBaseParams
-from uipath.eval.evaluators import JsonSimilarityEvaluator
-from uipath.eval.models.models import AgentExecution, EvaluatorCategory, EvaluatorType
+from uipath.eval.evaluators import LegacyJsonSimilarityEvaluator
+from uipath.eval.models.models import (
+    AgentExecution,
+    LegacyEvaluatorCategory,
+    LegacyEvaluatorType,
+)
 
 
 def _make_base_params() -> EvaluatorBaseParams:
     return EvaluatorBaseParams(
         id="json-sim",
-        category=EvaluatorCategory.Deterministic,
-        evaluator_type=EvaluatorType.JsonSimilarity,
+        category=LegacyEvaluatorCategory.Deterministic,
+        evaluator_type=LegacyEvaluatorType.JsonSimilarity,
         name="JSON Similarity",
         description="Compares JSON structures",
         created_at="2025-01-01T00:00:00Z",
@@ -28,7 +32,7 @@ def _make_base_params() -> EvaluatorBaseParams:
 class TestJsonSimilarityEvaluator:
     @pytest.mark.asyncio
     async def test_json_similarity_exact_score_1(self) -> None:
-        evaluator = JsonSimilarityEvaluator(
+        evaluator = LegacyJsonSimilarityEvaluator(
             **_make_base_params().model_dump(),
         )
         expected_json = """
@@ -73,7 +77,7 @@ class TestJsonSimilarityEvaluator:
 
     @pytest.mark.asyncio
     async def test_json_similarity_exact_score_2(self) -> None:
-        evaluator = JsonSimilarityEvaluator(
+        evaluator = LegacyJsonSimilarityEvaluator(
             **_make_base_params().model_dump(),
         )
         expected_json = """
@@ -109,7 +113,7 @@ class TestJsonSimilarityEvaluator:
 
     @pytest.mark.asyncio
     async def test_json_similarity_exact_score_3(self) -> None:
-        evaluator = JsonSimilarityEvaluator(
+        evaluator = LegacyJsonSimilarityEvaluator(
             **_make_base_params().model_dump(),
         )
         expected_json = """
@@ -142,7 +146,7 @@ class TestJsonSimilarityEvaluator:
 
     @pytest.mark.asyncio
     async def test_json_similarity_exact_score_4(self) -> None:
-        evaluator = JsonSimilarityEvaluator(
+        evaluator = LegacyJsonSimilarityEvaluator(
             **_make_base_params().model_dump(),
         )
         expected_json = """
